@@ -1,13 +1,17 @@
 package main
 
 import (
-	//"context"
 	"os"
 	"runtime"
 
+	"github.com/openshift/cluster-samples-operator/pkg/metrics"
 	"github.com/openshift/cluster-samples-operator/pkg/operator"
 	"github.com/openshift/cluster-samples-operator/pkg/signals"
 
+	"github.com/openshift/library-go/pkg/operator/watchdog"
+
+	"github.com/spf13/cobra"
+
 	"github.com/sirupsen/logrus"
 	_ "k8s.io/client-go/plugin/pkg/client/auth/gcp"
 )
@@ -18,20 +22,34 @@ func printVersion() {
 }
 
 func main() {
+	cmd := &cobra.Command{
+		Use:   "cluster-samples-operator",
+		Short: "OpenShift cluster samples operator",
+		Run:   runOperator,
+	}
+	cmd.AddCommand(watchdog.NewFileWatcherWatchdog())
+	if err := cmd.Execute(); err != nil {
+		logrus.Errorf("%v", err)
+		os.Exit(1)
+	}
+}
+
+func runOperator(cmd *cobra.Command, args []string) {
 	printVersion()
 
-	if os.Args != nil && len(os.Args) > 0 {
-		for _, arg := range os.Args {
-			if arg == "-v" {
-				logrus.SetLevel(logrus.DebugLevel)
-				break
-			}
+	for _, arg := range args {
+		if arg == "-v" {
+			logrus.SetLevel(logrus.DebugLevel)
+			break
 		}
 	}
 
 	// set up signals so we handle the first shutdown signal gracefully
 	stopCh := signals.SetupSignalHandler()
 
+	srv := metrics.BuildServer(metrics.MetricsPort)
+	go metrics.RunServer(srv, stopCh)
+
 	controller, err := operator.NewController()
 	if err != nil {
 		logrus.Fatal(err)
